# bargtd
A GTD Tool on your OS menu bar

## TODO

* [x] support create new task from menu
* [x] support merge multiple tasklist
* [x] support JIRA
* [ ] support custom query from github
* [ ] support switch profile from menu
* [ ] support create new task in merge mode
* [ ] use `asyncio` when fetch data from remote
* [ ] put the gitlab private token in header: [ref](https://docs.gitlab.com/ee/api/#personal-access-tokens)
